**NOTES

*******************************************
*******************************************
***THIS PROGRAM RUNS MasterMerged_PS2023_JMCB.dta TO EVALUATE IMPACT OF***
***CHINESE IPO SUSPENSIONS ON LISTED STOCKS*****************
****DATES BASED ON CITED JFQA PAPER*************************************************
********************************
****************************************************************

**************************************************************
***WE CLUSTER THROUGHOUT BY INDUSTRY*************************
***WINSORIZE AT 1%*******************************



****SET UP LOG ****

clear

*
set more 1
*

* Read in the data set
*

use "mastermerged_PS2023_JMCB.dta", clear




*Winsorizing some variables 

winsor2 pb_ma_, suffix(w1) cuts(1 99)
winsor2 lev_ma_, suffix(w1) cuts(1 99)
winsor2 NPM, suffix(_w1) cuts(1 99)
winsor2 AROA, suffix(_w1) cuts(1 99)
winsor2 AROE, suffix(_w1) cuts(1 99)
winsor2 ROIK, suffix(_w1) cuts(1 99)
winsor2 OC_OR, suffix(_w1) cuts(1 99)
winsor2 impactM, suffix(_w1) cuts(1 99)
winsor2 covU_firm, suffix(_w1) cuts(1 99)
winsor2 impactM_adj, suffix(_w1) cuts(1 99)


*Identify new variables

*Create variable "soe" that takes value 1 if firm was soe on event date, 0 otherwise

gen SOE = 0

replace SOE = 1 if stateowned_2008_dummy == 1

replace SOE = 1 if stateowned_2012_dummy == 1

replace SOE = 1 if stateowned_2015_dummy == 1

*Create numerical value of exchanges

gen Shanghai = 0

replace Shanghai = 1 if exchanges == "SH"

gen d2008 = 1

replace d2008 = 0 if d2012 == 1 | d2015 ==1


*****INTERACTIVE VARIABLES************
****************************************
*Want to identify interactive variables, but performance variables need to be converted 
*to positive values so firms with 0 exposure are lowest
* method is simply to add the lowest negative integer for each performance variable
*This preserves distribution of performance variables.
*Note we work with winsorized versions of performance variables, choosing 1% threshold
****************

*FIRST WE SUMMARIZE VALUES OF PERFORMANCE VARIABLES


sum NPM_w1 AROA_w1 AROE_w1 ROIK_w1 OC_OR_w1 if er3FA1 !=. & NPM !=. & impactM2 !=. & covU_ind2 & lev_ma_w1 !=. & sd_EBIT_  !=.

*THEN WE ADJUST PERF VARIABLES BY ADDING SMALLEST NEGATIVE NUMBER FOR EACH VARIABLES, SO VARIABLE IS ALWAYS POSITIVE
*THESE VALUES CORRESPOND TO WINSORIZING AT 1% LEVEL


gen NPM_a = NPM_w1 +100.86
gen AROA_a = AROA_w1 +22.48
gen AROE_a = AROE_w1 +64.1
gen ROIK_a = ROIK_w1 +31.13
gen OR_OC_a = 1/OC_OR_w1 


*************************
***CHECK IF THIS IS STILL OK
***************************


replace DA4 = 0 if impactM == 0

******************************
****GEN INTERACTIVE FOR impactM_adj
***********************************

gen intimpMNPM_a = 0
replace intimpMNPM_a = impactM_adj * NPM_a

gen intimpMAROA_a = 0
replace intimpMAROA_a = impactM_adj * AROA_a

gen intimpMAROE_a = 0
replace intimpMAROE_a = impactM_adj * AROE_a


gen intimpMROIK_a = 0
replace intimpMROIK = impactM_adj * ROIK_a

gen intimpMOR_OC_a = 0
replace intimpMOR_OC_a = impactM_adj * OR_OC_a





**********************
**time VARIABLE***********
**********************


gen time = 1
replace time = 2 if d2012 == 1
replace time = 3 if d2015 == 1

*label variable erA1 "One day excess return"

*******************************
****GENERATE NUMERICAL VALURES FROM PROVINCIAL STRINGS**
***********************************

egen provnum = group(provCode)


****************************************
************************************
***ALTERNATIVE INDUSTRY CLASSIFICATIONS**
***************************************
********************************************

******************************
****GEN INTERACTIVE FOR impactM1 through impactM4 and covU_ind1 through covU_ind4
***********************************

gen intimpM1NPM = 0
replace intimpM1NPM = impactM1 * NPM_a

gen intimpM2NPM = 0
replace intimpM2NPM = impactM2 * NPM_a

gen intimpM3NPM = 0
replace intimpM3NPM = impactM3 * NPM_a

gen intimpM4NPM = 0
replace intimpM4NPM = impactM4 * NPM_a

gen intcovU1NPM = 0
replace intcovU1NPM = covU_ind1 * NPM_a

gen intcovU2NPM = 0
replace intcovU2NPM = covU_ind2 * NPM_a

gen intcovU3NPM = 0
replace intcovU3NPM = covU_ind3 * NPM_a

gen intcovU4NPM = 0
replace intcovU4NPM = covU_ind4 * NPM_a

gen intimpM_adjNPM = 0
replace intimpM_adjNPM = impactM_adj * NPM_a

gen intimpM2_adjNPM = 0
replace intimpM2_adjNPM = impactM_adj * NPM_a




*******************************************
****GENERATE RESIDUALS FOR ALTERNATIVE INDUSTRY CLASSIFICATIONS**
*********************************************

regress covU_ind1 impactM1
predict covU1_pred
predict covU1_resid, residuals
gen intcovU1rNPM = 0
replace intcovU1rNPM = covU1_resid * NPM_a

regress covU_ind2 impactM2
predict covU2_pred
predict covU2_resid, residuals
gen intcovU2rNPM = 0
replace intcovU2rNPM = covU2_resid * NPM_a

regress covU_ind3 impactM3
predict covU3_pred
predict covU3_resid, residuals
gen intcovU3rNPM = 0
replace intcovU3rNPM = covU3_resid * NPM_a

regress covU_ind4 impactM4
predict covU4_pred
predict covU4_resid, residuals
gen intcovU4rNPM = 0
replace intcovU4rNPM = covU4_resid * NPM_a

regress covU_ind2 impactM2_adj
predict covU2_a_pred
predict covU2_a_resid, residuals
gen intcovU2arNPM = 0
replace intcovU2arNPM = covU2_a_resid * NPM_a


******************************
****GEN INTERACTIVE FOR D4_adj
***********************************

gen intD4NPM = 0
replace intD4NPM = D4_adj * NPM_a

******************************
****GEN RESIDUALS FOR D4_adj
***********************************

regress covU_ind2 D4_adj
predict covU2D_pred
predict covU2D_resid, residuals
gen intcovU2DrNPM = 0
replace intcovU2DrNPM = covU2D_resid * NPM_a

*****************************
***GEN INTERACTIVE FOR OTHER PERFORMANCE VARIABLES*************
*******************************************************

gen intimpM2AROE = 0
replace intimpM2AROE = impactM2 * AROE_a

gen intimpM2AROA = 0
replace intimpM2AROA = impactM2 * AROA_a

gen intimpM2ROIK = 0
replace intimpM2ROIK = impactM2 * ROIK_a

gen intimpM2OR_OC = 0
replace intimpM2OR_OC = impactM2 * OR_OC_a

gen intcovU2DrAROA = 0
replace intcovU2DrAROA = covU2D_resid * AROA_a

gen intcovU2DrAROE = 0
replace intcovU2DrAROE = covU2D_resid * AROE_a

gen intcovU2DrROIK = 0
replace intcovU2DrROIK = covU2D_resid * ROIK_a

gen intcovU2DrOR_OC = 0
replace intcovU2DrOR_OC = covU2D_resid * OR_OC_a



***********************************
***********************************
*******TABLE 2********************
****SUMMARY STATISICS*****************
**************************************
**ONLY USES OBSERVATIONS ARE NOT MISSING VARIABLES IN OUR BASE SPECIFICATION****
****************************

est clear 

gen intCOVSOE = 0

gen intimpactMSOE = 0

replace intCOVSOE = covU_firm * SOE

replace intimpactMSOE = impactM * SOE

eststo: sum er3FA1 D4_adj impactM2 NPM_a covU_ind2 lev_ma_w1 pb_ma_w1 sd_EBIT_ SOE Shanghai if er3FA1 !=. & NPM_a !=. & impactM2 !=. & intimpM2NPM !=. & covU2_resid !=. & intcovU2rNPM !=. & lev_ma_w1 !=. & sd_EBIT_  !=.

*DETAILED SUMMARY TO IDENTIFY MEDIAN VALUES

eststo: sum er3FA1 D4_adj impactM2 NPM_a covU_ind2 lev_ma_w1 pb_ma_w1 sd_EBIT_ SOE Shanghai if er3FA1 !=. & NPM_a !=. & impactM2 !=. & intimpM2NPM !=. & covU2_resid !=. & intcovU2rNPM !=. & lev_ma_w1 !=. & sd_EBIT_  !=., detail

corr impactM2 covU_ind2 if er3FA1 !=. & NPM_a !=. & impactM2 !=. & intimpM2NPM !=. & covU2_resid !=. & intcovU2rNPM !=. & lev_ma_w1 !=. & sd_EBIT_  !=.

esttab using "table2.tex", ///
	replace label ///
	title("Table 2. Summary statistics") ///
	addnote("Note: ")

******************************
******TABLE 3******************
***BASE SPECIFICATION*********
***INCLUDES PROVINCIAL DUMMIES
***ALL TIME DUMMIES******
****RESIDUAL OF COV IND (AND COV IND INSTEAD OF COV_FIRM)****
*******************************
**********************************

est clear

*FULL SPEC

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

*DROP INTERACTIVE TERMS

eststo: regress er3FA1 NPM_a impactM2 covU2_resid lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)


*DROP COVU_RESID AND INTCOVURNPM

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

*DROP impactM2 intimpM2NPM  USE COVU_IND AND intCOViNPM INSTEAD OF COVU_RESID AND INTCOVURNPM

eststo: regress er3FA1 NPM_a covU_ind2 intcovU2NPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

**D4_adj ACCOUNTS FOR DELAY IN IPO
*D4_adj INSTEAD of IMPACTM*

eststo: regress er3FA1 NPM_a D4_adj intD4NPM covU2_resid intcovU2DrNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)


*IMPACTM2_ADJ ADJUSTS FOR "QUALITY" OF IPO

*FULL SPEC IMPACTM_ADJ

eststo: regress er3FA1 NPM_a impactM2_adj intimpM2_adjNPM covU2_a_resid intcovU2arNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

esttab using "table3.tex", ///
	replace label se ///
	title("Table 3. Base specification") ///
	addnote("Note: ") ///
	r2(3)

********************************
******TABLE 4******************
***CHANGES IN SPECIFICATION****
********************************

est clear

**Raw NOT EXCESS RETURN

eststo: regress rA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

**2 DAY EXCESS RETURN***

eststo: regress er3FA2 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)


**DROP NPM**

eststo: regress er3FA1 impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_w1 != ., noconstant vce(cluster indcode)

*DROP PROVINCIAL DUMMIES

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 if NPM_a != ., noconstant vce(cluster indcode)


****THIS REGRESSION DROPPED FOR SPACE
**DROP CONDITIONING VARIABLES**

*eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM d2008 d2012 d2015 i.provnum if NPM_w1 != ., noconstant vce(cluster indcode)

**ADD PRO

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai PRO d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

*MACRO VARIABLES INSTEAD OF DUMMIES

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai uncertainty epu i.provnum if NPM_a != ., noconstant vce(cluster indcode)

esttab using "table4.tex", ///
	replace label se ///
	title("Table 4. Changes in specification") ///
	addnote("Note: Dependent variable is one-day excess return on equity, except Model 1, whose dependent variable is the 1-day raw return on equity, and Model 2, whose dependent variable is the 2-day excess return on equity. Ordinary least squares estimation, with standard errors clustered by industry in parentheses. See text for variable definitions and details on sample perturbations.") ///
	r2(3)


******************************
******TABLE 5******************
***CHANGES IN SAMPLE**********
********************************

est clear

*BALANCED SAMPLE (DROP FIRMS NOT LISTED FOR ALL THREE EVENTS) 

preserve

bysort stockCode: egen max_2008 = max(d2008)
bysort stockCode: egen max_2012 = max(d2012)
bysort stockCode: egen max_2015 = max(d2015)
bysort stockCode: keep if max_2008 == 1 & max_2012 == 1 & max_2015==1

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

restore

***SOE ONLY*****

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != . & SOE == 1, noconstant vce(cluster indcode)


***POE ONLY*****

eststo: regress er3FA1 NPM_a impactM intimpM2NPM  covU2_resid intcovU2rNPM lev_ma_w1 pb_ma_w1 sd_EBIT_ SOE Shanghai d2012 d2015 if NPM_a != . & SOE == 0, vce(cluster indcode)


***SHANGHAI ONLY*****

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE d2008 d2012 d2015 i.provnum if NPM_a != . & Shanghai == 1, noconstant vce(cluster indcode)

***SHENZHEN ONLY*****

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE d2008 d2012 d2015 i.provnum if NPM_a != . & Shanghai == 0, noconstant vce(cluster indcode)



*DROP PROFITABLE (NPM MORE THAN THREE STANDARD DEVIATIONS ABOVE MEAN)

preserve

drop if er3FA1 ==. | NPM_a ==. | impactM2 ==. | intimpM2NPM ==. | covU2_resid ==. | intcovU2rNPM ==. | lev_ma_w1 ==. | sd_EBIT_  ==.

 foreach v in NPM{
	quietly sum `v'
	gen sd_`v' = `r(sd)' 
	gen mean_`v' = `r(mean)' 
	gen z_score_`v' = (`v'- mean_`v') / sd_`v'
	drop if z_score_`v' > 3 
}

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 pb_ma_w1 sd_EBIT_ SOE Shanghai d2012 d2015 i.provnum if NPM_a != ., vce(cluster indcode)

restore

*DROP UNPROFITABLE (NPM MORE THAN THREE STANDARD DEVIATIONS BELOW MEAN)

preserve

drop if er3FA1 ==. | NPM_a ==. | impactM2 ==. | intimpM2NPM ==. | covU2_resid ==. | intcovU2rNPM ==. | lev_ma_w1 ==. | sd_EBIT_  ==.

foreach v in NPM{
	quietly sum `v'
	gen sd_`v' = `r(sd)' 
	gen mean_`v' = `r(mean)' 
	gen z_score_`v' = (`v'- mean_`v') / sd_`v'
	drop if z_score_`v' < -3 
}

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

restore



*DROP PRODUCTIVE (OR_OC MORE THAN THREE STANDARD DEVIATIONS ABOVE MEAN)

preserve

drop if er3FA1 ==. | NPM_a ==. | impactM2 ==. | intimpM2NPM ==. | covU2_resid ==. | intcovU2rNPM ==. | lev_ma_w1 ==. | sd_EBIT_  ==.


foreach v in OC_OR{
	quietly sum `v'
	gen sd_`v' = `r(sd)' 
	gen mean_`v' = `r(mean)' 
	gen z_score_`v' = (`v'- mean_`v') / sd_`v'
	drop if z_score_`v' > 3 
}

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

restore
 
*DROP UNPRODUCTIVE (OR_OC MORE THAN THREE STANDARD DEVIATIONS BELOW MEAN)

*****NB THIS DROPPED NO OBSERVATIONS RELATIVE TO SAMPLE**********
****SKIP IN TEXT AND MENTION IN FOOTNOTE*************

preserve

drop if er3FA1 ==. | NPM_a ==. | impactM2 ==. | intimpM2NPM ==. | covU2_resid ==. | intcovU2rNPM ==. | lev_ma_w1 ==. | sd_EBIT_  ==.

foreach v in OC_OR{
	quietly sum `v'
	gen sd_`v' = `r(sd)' 
	gen mean_`v' = `r(mean)' 
	gen z_score_`v' = (`v'- mean_`v') / sd_`v'
	drop if z_score_`v' < -3 
}

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

restore



*DROP BIG (MORE THAN THREE STANDARD DEVIATIONS ABOVE MEAN)

preserve

drop if er3FA1 ==. | NPM_a ==. | impactM2 ==. | intimpM2NPM ==. | covU2_resid ==. | intcovU2rNPM ==. | lev_ma_w1 ==. | sd_EBIT_  ==.

foreach v in asst_ma_{
	quietly sum `v'
	gen sd_`v' = `r(sd)' 
	gen mean_`v' = `r(mean)' 
	gen z_score_`v' = (`v'- mean_`v') / sd_`v'
	drop if z_score_`v' > 3 
}

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

restore
 
*DROP SMALL (MORE THAN THREE STANDARD DEVIATIONS BELOW MEAN)
****************************
*****NB THIS DROPPED NO OBSERVATIONS RELATIVE TO SAMPLE**********
****COULD SKIP IN TEXT AND MENTION IN FOOTNOTE*************



preserve

drop if er3FA1 ==. | NPM_a ==. | impactM2 ==. | intimpM2NPM ==. | covU2_resid ==. | intcovU2rNPM ==. | lev_ma_w1 ==. | sd_EBIT_  ==.

foreach v in asst_ma_{
	quietly sum `v'
	gen sd_`v' = `r(sd)' 
	gen mean_`v' = `r(mean)' 
	gen z_score_`v' = (`v'- mean_`v') / sd_`v'
	drop if z_score_`v' < -3 
}

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

restore


 
*DROP FIRMS FROM INDUSTRIES WITH LARGE VALUES OF IMPACTM2 (MORE THAN THREE STANDARD DEVIATIONS ABOVE MEAN)

preserve


drop if er3FA1 ==. | NPM_a ==. | impactM2 ==. | intimpM2NPM ==. | covU2_resid ==. | intcovU2rNPM ==. | lev_ma_w1 ==. | sd_EBIT_  ==.

foreach v in impactM2{
	quietly sum `v'
	gen sd_`v' = `r(sd)' 
	gen mean_`v' = `r(mean)' 
	gen z_score_`v' = (`v'- mean_`v') / sd_`v'
	drop if z_score_`v' > 3 
}

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

restore

*DROP FIRMS FROM INDUSTRIES WITH IMPACTM2 = 0 (MORE THAN THREE STANDARD DEVIATIONS ABOVE MEAN)

preserve

drop if er3FA1 ==. | NPM_a ==. | impactM2 == 0 | intimpM2NPM ==. | covU2_resid ==. | intcovU2rNPM ==. | lev_ma_w1 ==. | sd_EBIT_  ==.

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

restore 

esttab using "table5.tex", ///
	replace label se ///
	title("Table 5. Changes in sample") ///
	addnote("Note: ") ///
	r2(3)

*********************************
***TABLE 6*********************
****CHANGES IN ESTIMATION METHODOLOGY**
*****************************************

est clear

****ROBUST STANDARD ERRORS*****

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant robust

****REGULAR STANDARD ERRORS*****

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant 

***WEIGHTED LEAST SQUARES (IMPACTM2)

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum [aw = impactM2] if NPM_a != ., noconstant

***WEIGHTED LEAST SQUARES (ASST_MA)

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum [aw = asst_ma_] if NPM_a != ., noconstant

**********************
************************

	
. 
*TRIM RATHER THAN WINSORIZE
. 

preserve

foreach v in lev_ma_ pb_ma_{
	qui sum `v', detail
	gen `v'_p1 = `r(p1)'
	gen `v'_p99 = `r(p99)'
	drop if `v' < `v'_p1 | `v' > `v'_p99
}

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)



restore


esttab using "table6.tex", ///
	replace label se ///
	title("Table 6. Changes in estimation") ///
	addnote("Note: ") ///
	r2(3)

*
* Clean up and close down
*
drop _all
log close
set more 0
exit,clear



