**NOTES

*******************************************
*******************************************
***THIS PROGRAM RUNS MasterMerged_PS_JMCB.dta TO GENERATE ONLINE APPENDIX TABLES FOR PACKER AND SPIEGEL 2023**
***CHINESE IPO SUSPENSIONS ON LISTED STOCKS*****************
**************************************************
*******************************
****************************************************************

**************************************************************
***WE CLUSTER THROUGHOUT BY INDUSTRY*************************
***WINSORIZE AT 1%*******************************



****SET UP LOG ****

clear
tables_appendix.log", replace text

*
set more 1
*
* **********
*FIRST SOME PRELIMINARY DATA STUFF
* Data massaging
*
* Read in the data set
*

*Mark:
use "mastermerged_PS_JMCB.dta", clear






*Winsorizing some variables 

winsor2 pb_ma_, suffix(w1) cuts(1 99)
winsor2 lev_ma_, suffix(w1) cuts(1 99)
winsor2 NPM, suffix(_w1) cuts(1 99)
winsor2 AROA, suffix(_w1) cuts(1 99)
winsor2 AROE, suffix(_w1) cuts(1 99)
winsor2 ROIK, suffix(_w1) cuts(1 99)
winsor2 OC_OR, suffix(_w1) cuts(1 99)
winsor2 impactM, suffix(_w1) cuts(1 99)
winsor2 covU_firm, suffix(_w1) cuts(1 99)
winsor2 impactM_adj, suffix(_w1) cuts(1 99)


*Identify new variables

*Create variable "soe" that takes value 1 if firm was soe on event date, 0 otherwise

gen SOE = 0

replace SOE = 1 if stateowned_2008_dummy == 1

replace SOE = 1 if stateowned_2012_dummy == 1

replace SOE = 1 if stateowned_2015_dummy == 1

*Create numerical value of exchanges

gen Shanghai = 0

replace Shanghai = 1 if exchanges == "SH"

gen d2008 = 1

replace d2008 = 0 if d2012 == 1 | d2015 ==1


*****INTERACTIVE VARIABLES************
****************************************
*Want to identify interactive variables, but performance variables need to be converted 
*to positive values so firms with 0 exposure are lowest
* method is simply to add the lowest negative integer for each performance variable
*This preserves distribution of performance variables.
*Note we work with winsorized versions of performance variables, choosing 1% threshold
****************

*FIRST WE SUMMARIZE VALUES OF PERFORMANCE VARIABLES


sum NPM_w1 AROA_w1 AROE_w1 ROIK_w1 OC_OR_w1 if er3FA1 !=. & NPM !=. & impactM2 !=. & covU_ind2 & lev_ma_w1 !=. & sd_EBIT_  !=.

*THEN WE ADJUST PERF VARIABLES BY ADDING SMALLEST NEGATIVE NUMBER FOR EACH VARIABLES, SO VARIABLE IS ALWAYS POSITIVE
*THESE VALUES CORRESPOND TO WINSORIZING AT 1% LEVEL


gen NPM_a = NPM_w1 +100.86
gen AROA_a = AROA_w1 +22.48
gen AROE_a = AROE_w1 +64.1
gen ROIK_a = ROIK_w1 +31.13
gen OR_OC_a = 1/OC_OR_w1 


*************************
***CHECK IF THIS IS STILL OK
***************************


replace DA4 = 0 if impactM == 0

******************************
****GEN INTERACTIVE FOR impactM_adj
***********************************

gen intimpMNPM_a = 0
replace intimpMNPM_a = impactM_adj * NPM_a

gen intimpMAROA_a = 0
replace intimpMAROA_a = impactM_adj * AROA_a

gen intimpMAROE_a = 0
replace intimpMAROE_a = impactM_adj * AROE_a


gen intimpMROIK_a = 0
replace intimpMROIK = impactM_adj * ROIK_a

gen intimpMOR_OC_a = 0
replace intimpMOR_OC_a = impactM_adj * OR_OC_a





**********************
**time VARIABLE***********
**********************


gen time = 1
replace time = 2 if d2012 == 1
replace time = 3 if d2015 == 1

*label variable erA1 "One day excess return"

*******************************
****GENERATE NUMERICAL VALURES FROM PROVINCIAL STRINGS**
***********************************

egen provnum = group(provCode)


****************************************
************************************
***ALTERNATIVE INDUSTRY CLASSIFICATIONS**
***************************************
********************************************

******************************
****GEN INTERACTIVE FOR impactM1 through impactM4 and covU_ind1 through covU_ind4
***********************************

gen intimpM1NPM = 0
replace intimpM1NPM = impactM1 * NPM_a

gen intimpM2NPM = 0
replace intimpM2NPM = impactM2 * NPM_a

gen intimpM3NPM = 0
replace intimpM3NPM = impactM3 * NPM_a

gen intimpM4NPM = 0
replace intimpM4NPM = impactM4 * NPM_a

gen intcovU1NPM = 0
replace intcovU1NPM = covU_ind1 * NPM_a

gen intcovU2NPM = 0
replace intcovU2NPM = covU_ind2 * NPM_a

gen intcovU3NPM = 0
replace intcovU3NPM = covU_ind3 * NPM_a

gen intcovU4NPM = 0
replace intcovU4NPM = covU_ind4 * NPM_a

gen intimpM_adjNPM = 0
replace intimpM_adjNPM = impactM_adj * NPM_a

gen intimpM2_adjNPM = 0
replace intimpM2_adjNPM = impactM_adj * NPM_a




*******************************************
****GENERATE RESIDUALS FOR ALTERNATIVE INDUSTRY CLASSIFICATIONS**
*********************************************

regress covU_ind1 impactM1
predict covU1_pred
predict covU1_resid, residuals
gen intcovU1rNPM = 0
replace intcovU1rNPM = covU1_resid * NPM_a

regress covU_ind2 impactM2
predict covU2_pred
predict covU2_resid, residuals
gen intcovU2rNPM = 0
replace intcovU2rNPM = covU2_resid * NPM_a

regress covU_ind3 impactM3
predict covU3_pred
predict covU3_resid, residuals
gen intcovU3rNPM = 0
replace intcovU3rNPM = covU3_resid * NPM_a

regress covU_ind4 impactM4
predict covU4_pred
predict covU4_resid, residuals
gen intcovU4rNPM = 0
replace intcovU4rNPM = covU4_resid * NPM_a

regress covU_ind2 impactM2_adj
predict covU2_a_pred
predict covU2_a_resid, residuals
gen intcovU2arNPM = 0
replace intcovU2arNPM = covU2_a_resid * NPM_a


******************************
****GEN INTERACTIVE FOR D4_adj
***********************************

gen intD4NPM = 0
replace intD4NPM = D4_adj * NPM_a

******************************
****GEN RESIDUALS FOR D4_adj
***********************************

regress covU_ind2 D4_adj
predict covU2D_pred
predict covU2D_resid, residuals
gen intcovU2DrNPM = 0
replace intcovU2DrNPM = covU2D_resid * NPM_a

*****************************
***GEN INTERACTIVE FOR OTHER PERFORMANCE VARIABLES*************
*******************************************************

gen intimpM2AROE = 0
replace intimpM2AROE = impactM2 * AROE_a

gen intimpM2AROA = 0
replace intimpM2AROA = impactM2 * AROA_a

gen intimpM2ROIK = 0
replace intimpM2ROIK = impactM2 * ROIK_a

gen intimpM2OR_OC = 0
replace intimpM2OR_OC = impactM2 * OR_OC_a

gen intcovU2DrAROA = 0
replace intcovU2DrAROA = covU2D_resid * AROA_a

gen intcovU2DrAROE = 0
replace intcovU2DrAROE = covU2D_resid * AROE_a

gen intcovU2DrROIK = 0
replace intcovU2DrROIK = covU2D_resid * ROIK_a

gen intcovU2DrOR_OC = 0
replace intcovU2DrOR_OC = covU2D_resid * OR_OC_a


****************************
****APPENDIX TABLE A2**************
***other performance variables***
*************************************

est clear

eststo: regress er3FA1 AROA_a impactM2 intimpM2AROA covU2_resid intcovU2DrAROA lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

eststo: regress er3FA1 AROE_a  impactM2 intimpM2AROE covU2_resid intcovU2DrAROE lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

eststo: regress er3FA1 ROIK_a impactM2 intimpM2ROIK covU2_resid intcovU2DrROIK lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

eststo: regress er3FA1 OR_OC_a impactM2 intimpM2OR_OC covU2_resid intcovU2DrOR_OC lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

esttab using "tableA2.tex", ///
	replace label se ///
	title("Table A2. Other performance variables") ///
	addnote("Note: ") ///
	r2(3)

****************************
***TABLE A3****************
*************************
**INDIVIDUAL EVENT DATES**
****************************

est clear

*FIRST EVENT ONLY

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai i.provnum if NPM_a != . & d2008 == 1, noconstant vce(cluster indcode)

*regress er3FA1 NPM_a DA4 impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

*SECOND EVENT ONLY

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai i.provnum if NPM_a != . & d2012 == 1, noconstant vce(cluster indcode)

*regress er3FA1 NPM_a DA4 impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)


*THIRD EVENT ONLY

eststo: regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai i.provnum if NPM_a != . & d2015 == 1, noconstant vce(cluster indcode)

*regress er3FA1 NPM_a DA4 impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2008 d2012 d2015 i.provnum if NPM_a != ., noconstant vce(cluster indcode)

esttab using "tableA3.tex", ///
	replace label se ///
	title("Table A3. Individual event dates") ///
	addnote("Note: ") ///
	r2(3)

**********************
*TABLE A4*********************
**OTHER INDUSTRY CLASSIFICATIONS**
***************************

est clear

*ONE DIGIT INDUSTRIES

eststo: regress er3FA1 NPM_a impactM1 intimpM1NPM covU1_resid intcovU1rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2012 d2015 i.provnum if NPM_a != ., vce(cluster indcode)

*THREE DIGIT INDUSTRIES

eststo: regress er3FA1 NPM_a impactM3 intimpM3NPM covU3_resid intcovU3rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2012 d2015 i.provnum if NPM_a != ., vce(cluster indcode)

*FOUR DIGIT INDUSTRIES

eststo: regress er3FA1 NPM_a impactM4 intimpM4NPM covU4_resid intcovU4rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2012 d2015 i.provnum if NPM_a != ., vce(cluster indcode)

***********************
***FOR RESPONSE TO REVIEWERS****
**********************************

**ADD PRO DROP PROVINCIAL DUMMIES******

regress er3FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai PRO d2008 d2012 d2015 if NPM_a != ., noconstant vce(cluster indcode)

*FIVE FACTOR FAMA FRENCH

regress er5FA1 NPM_a impactM2 intimpM2NPM covU2_resid intcovU2rNPM lev_ma_w1 sd_EBIT_ SOE Shanghai d2012 d2015 i.provnum if NPM_a != ., vce(cluster indcode)


esttab using "tableA4.tex", ///
	replace label se ///
	title("Table A4. Other industry classifications") ///
	addnote("Note: ") ///
	r2(3)

*
* Clean up and close down
*
drop _all
log close
set more 0
exit,clear